@@ -48,7 +48,7 @@ void  CatJob::ShowRunStatus(StatusLine *s)
    }
    else
    {
-      s->Show("Waiting for filter to terminate");
+      s->Show(_("Waiting for filter to terminate"));
    }
 }
 
@@ -62,7 +62,8 @@ void  CatJob::PrintStatus(int verbose)
    }
    if(curr==0)
    {
-      printf("\tWaiting for filter to terminate\n");
+      putchar('\t');
+      puts(_("Waiting for filter to terminate"));
       return;
    }
    XferJob::PrintStatus(verbose);
@@ -70,6 +71,8 @@ void  CatJob::PrintStatus(int verbose)
 
 int   CatJob::Do()
 {
+   RateDrain();
+
    int m=STALL;
    int res;
 
@@ -105,15 +108,15 @@ int   CatJob::Do()
       {
 	 if(!rg->Done())
 	    return m;
-	 
+
 	 char **files,**i;
 	 m=MOVED;
-      
+
 	 files=rg->GetResult();
 	 if(rg->Error())
 	    eprintf("rglob: %s - %s\n",rg->pattern,session->StrError(rg->ErrorCode()));
 	 else if(!files)
-	    eprintf("%s: no files found\n",rg->pattern);
+	    eprintf(_("%s: no files found\n"),rg->pattern);
 	 else
 	 {
 	    for(i=files; *i; i++)
@@ -194,6 +197,9 @@ int   CatJob::Do()
 
 void CatJob::NextFile()
 {
+   if(!args_globbed)
+      return;
+
    if(curr)
    {
       if(filter_wait)
@@ -289,6 +295,6 @@ CatJob::CatJob(FileAccess *new_session,FDStream *new_global,ArgV *args) : XferJo
       else
 	 global=new FDStream(1,"<stdout>");
    }
-   
+
    print_run_status=!global->usesfd(1);
 }
