@@ -27,6 +27,9 @@
 #include "ArgV.h"
 #include "Filter.h"
 #include "alias.h"
+#include "history.h"
+
+extern History cwd_history;
 
 #define	CMD(name) Job *CmdExec::do_##name()
 #define	in_CMD(name) Job *do_##name()
@@ -50,8 +53,18 @@ class CmdExec : public SessionJob
    char *next_cmd;
    char *cmd_buf;
    bool partial_cmd;
+   int alias_field; // length of expanded alias (and ttl for used_aliases)
 
    TouchedAlias *used_aliases;
+   void free_used_aliases()
+      {
+	 if(used_aliases)
+	 {
+	    TouchedAlias::FreeChain(used_aliases);
+	    used_aliases=0;
+	 }
+	 alias_field=0;
+      }
 
    enum
    {
@@ -100,6 +113,13 @@ class CmdExec : public SessionJob
 
    CmdFeeder *feeder;
 
+   char *old_cwd;
+   char *old_lcwd;
+
+   FILE *debug_file;
+   void CloseDebug();
+   int  OpenDebug(const char *file);
+
 public:
    void FeedCmd(const char *c);
    void PrependCmd(const char *c);
@@ -113,7 +133,7 @@ public:
    in_CMD(wait);  in_CMD(site);  in_CMD(subsh); in_CMD(mirror);
    in_CMD(mput);  in_CMD(mv);	 in_CMD(cat);   in_CMD(cache);
    in_CMD(mkdir); in_CMD(quote); in_CMD(scache);in_CMD(mrm);
-   in_CMD(ver);
+   in_CMD(ver);	  in_CMD(close); in_CMD(bookmark);
 
    static const char * const var_list[];
 
@@ -135,9 +155,6 @@ public:
    void SetCmdFeeder(CmdFeeder *new_feeder);
    void	RemoveFeeder();
 
-   static bool bootstrap;  // true while execing the first command from real argv[]
-   static bool want_terminate;
-
    friend char *command_generator(char *,int);	  // readline completor
    friend int remote_cmd(int);
 
@@ -164,6 +181,4 @@ public:
    void SetInteractive(bool i);
 };
 
-void move_to_background();
-
 #endif//CMDEXEC_H
