@@ -23,17 +23,14 @@
 
 #include "XferJob.h"
 #include "Filter.h"
-#include "mirror.h"
 
 class FileXfer : public XferJob
 {
 protected:
-   virtual void NextFile() = 0;
-
    FDStream *local;
-   
+
    bool cont;
-   
+
    ArgV	 *args;
 
    char *saved_cwd;
@@ -46,8 +43,6 @@ public:
    {
       args->Append(f1);
       args->Append(f2);
-      if(!curr)
-	 NextFile();
    }
 };
 
