@@ -28,6 +28,7 @@ class GetJob : public FileXfer
 protected:
    void	 NextFile();
 
+   time_t set_file_time;
    time_t file_time;
    bool delete_files:1;
    bool	deleting:1;
@@ -35,16 +36,15 @@ protected:
 public:
    int	 Do();
 
-   void SetTime(time_t t) { file_time=t; }
+   void SetTime(time_t t) { set_file_time=t; }
    void DeleteFiles() { delete_files=true; }
 
    GetJob(FileAccess *s,ArgV *args,bool cont=false)
       : FileXfer(s,args,cont)
    {
+      set_file_time=(time_t)-1;
       file_time=(time_t)-2;
       delete_files=deleting=false;
-      if(!curr && args && args->count()>1)
-	 NextFile();
    }
 };
 
