@@ -60,7 +60,7 @@ public:
    void	 Fg() { fg=true;  if(fg_data) fg_data->Fg(); }
 
    char	 *cmdline;
-   void ListJobs(int verbose_level,int indent=0);
+   virtual void ListJobs(int verbose_level,int indent=0);
    void ListDoneJobs();
    void BuryDoneJobs();
 
@@ -75,17 +75,15 @@ public:
    void SendSig(int n,int sig);
    void KillAll();
 
+   // CmdExec redefines this, and traps all messages of its children.
    virtual void vfprintf(FILE *file,const char *fmt,va_list v);
-   void eprintf(const char *fmt,...)
-#ifdef __GNUC__
-   __attribute__((format(printf,2,3)))
-#endif
-;
-   void fprintf(FILE *file,const char *fmt,...)
-#ifdef __GNUC__
-   __attribute__((format(printf,3,4)))
-#endif
-;
+
+   // C-like functions calling vfprintf
+   void eprintf(const char *fmt,...) PRINTF_LIKE(2,3);
+   void fprintf(FILE *file,const char *fmt,...) PRINTF_LIKE(3,4);
+   void printf(const char *fmt,...) PRINTF_LIKE(2,3);
+   void perror(const char *);
+   void puts(const char *);
 
    Job();
    virtual ~Job();
