@@ -26,16 +26,19 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <dirent.h>
 
 #include "LocalAccess.h"
 #include "ProtoList.h"
 #include "xmalloc.h"
+#include "xalloca.h"
 #include "xstring.h"
 #include "misc.h"
 
 void LocalAccess::ClassInit()
 {
-   new Protocol("file",LocalAccess::New);
+   // register the class
+   (void)new Protocol("file",LocalAccess::New);
 }
 
 void LocalAccess::Init()
@@ -73,37 +76,48 @@ int LocalAccess::Done()
       return error_code;
    if(done)
       return OK;
-   switch(mode)
+   switch((open_mode)mode)
    {
    case(CLOSED):
+   case(CONNECT_VERIFY):
       return OK;
-   case(CHANGE_DIR):
-   case(REMOVE):
-   case(REMOVE_DIR):
-   case(MAKE_DIR):
-   case(RENAME):
+   default:
       return IN_PROGRESS;
    }
-   return IN_PROGRESS;
 }
 
 int LocalAccess::Do()
 {
-   if(error_code<0)
+   if(error_code<0 || done)
       return STALL;
    int m=STALL;
-   switch(mode)
+   switch((open_mode)mode)
    {
    case(CLOSED):
       return m;
+   case(LIST):
    case(LONG_LIST):
+   case(QUOTE_CMD):
       if(stream==0)
       {
 	 char cmd[10+xstrlen(file)];
-	 if(file)
-	    sprintf(cmd,"ls -l %s",file);
-	 else
-	    sprintf(cmd,"ls -l");
+	 if(mode==LIST)
+	 {
+	    if(file && file[0])
+	       sprintf(cmd,"ls %s",file);
+	    else
+	       strcpy(cmd,"ls");
+	 }
+	 else if(mode==LONG_LIST)
+	 {
+	    if(file && file[0])
+	       sprintf(cmd,"ls -l %s",file);
+	    else
+	       strcpy(cmd,"ls -la");
+	 }
+	 else// if(mode==QUOTE_CMD)
+	    strcpy(cmd,file);
+	 DebugPrint("---- ",cmd);
 	 InputFilter *f_stream=new InputFilter(cmd);
 	 f_stream->SetCwd(cwd);
 	 stream=f_stream;
@@ -115,7 +129,8 @@ int LocalAccess::Do()
 	 if(stream->error())
 	 {
 	    error_code=FATAL;
-	    //FIXME
+	    xfree(last_error_resp);
+	    last_error_resp=xstrdup(stream->error_text);
 	    return MOVED;
 	 }
 	 block+=TimeOut(1000);
@@ -173,10 +188,19 @@ int LocalAccess::Do()
       }
       done=true;
       return MOVED;
+
    case(RETRIEVE):
+   case(STORE):
       if(stream==0)
       {
-	 stream=new FileStream(dir_file(cwd,file),O_RDONLY);
+	 int o_mode=O_RDONLY;
+	 if(mode==STORE)
+	 {
+	    o_mode=O_WRONLY|O_CREAT;
+	    if(pos==0)
+	       o_mode|=O_TRUNC;
+	 }
+	 stream=new FileStream(dir_file(cwd,file),o_mode);
 	 real_pos=-1;
 	 m=MOVED;
       }
@@ -184,22 +208,44 @@ int LocalAccess::Do()
       {
 	 if(stream->error())
 	 {
-	    error_code=FATAL;
-	    //FIXME
+	    error_code=NO_FILE;
+	    xfree(last_error_resp);
+	    last_error_resp=xstrdup(stream->error_text);
 	    return MOVED;
 	 }
 	 block+=TimeOut(1000);
 	 return m;
       }
       stream->Kill(SIGCONT);
-      block+=PollVec(stream->getfd(),POLLIN);
-      return m;
-   case(STORE):
+      block+=PollVec(stream->getfd(),(mode==STORE?POLLOUT:POLLIN));
       return m;
+
+   case(CONNECT_VERIFY):
+      done=true;
+      return MOVED;
+
+   case(ARRAY_INFO):
+      fill_array_info();
+      done=true;
+      return MOVED;
    }
    return m;
 }
 
+void LocalAccess::fill_array_info()
+{
+   for(int i=0; i<array_cnt; i++)
+   {
+      fileinfo *f = &array_for_info[i];
+      struct stat st;
+      if(stat(dir_file(cwd,f->file),&st)!=-1)
+      {
+	 f->size=st.st_size;
+	 f->time=st.st_mtime;
+      }
+   }
+}
+
 int LocalAccess::Read(void *buf,int size)
 {
    if(error_code<0)
@@ -304,14 +350,99 @@ void LocalAccess::Close()
    FileAccess::Close();
 }
 
-bool LocalAccess::SameLocationAs(FileAccess *fa,int)
+bool LocalAccess::SameLocationAs(FileAccess *fa)
 {
    if(!SameProtoAs(fa))
       return false;
    LocalAccess *o=(LocalAccess*)fa;
-   
+
    if(xstrcmp(home,o->home))
       return false;
 
    return !xstrcmp(cwd,o->cwd);
 }
+
+ListInfo *LocalAccess::MakeListInfo()
+{
+   return new LocalListInfo(cwd);
+}
+
+
+#ifndef S_ISLNK
+# define S_ISLNK(mode) (S_IFLNK==(mode&S_IFMT))
+#endif
+
+int LocalListInfo::Do()
+{
+   if(done)
+      return STALL;
+
+   DIR *d=opendir(dir);
+   struct dirent *f;
+
+   if(d==0)
+   {
+      const char *err=strerror(errno);
+      char *mem=(char*)alloca(strlen(err)+strlen(dir)+3);
+      sprintf(mem,"%s: %s",dir,err);
+      SetError(mem);
+      return MOVED;
+   }
+
+   result=new FileSet;
+   for(;;)
+   {
+      f=readdir(d);
+      if(f==0)
+	 break;
+      FileInfo *fi=new FileInfo();
+      fi->SetName(f->d_name);
+      result->Add(fi);
+   }
+   closedir(d);
+
+   result->Exclude(path,rxc_exclude,rxc_include);
+
+   result->rewind();
+   for(FileInfo *file=result->curr(); file!=0; file=result->next())
+   {
+      const char *name=dir_file(dir,file->name);
+
+      struct stat st;
+      if(lstat(name,&st)==-1)
+	 continue;
+
+      FileInfo::type t;
+      if(S_ISDIR(st.st_mode))
+	 t=FileInfo::DIRECTORY;
+      else if(S_ISREG(st.st_mode))
+	 t=FileInfo::NORMAL;
+#ifdef HAVE_LSTAT
+      else if(S_ISLNK(st.st_mode))
+	 t=FileInfo::SYMLINK;
+#endif
+      else
+	 continue;   // ignore other type files
+
+      file->SetSize(st.st_size);
+      file->SetDate(st.st_mtime);
+      file->SetMode(st.st_mode&07777);
+      file->SetType(t);
+
+#ifdef HAVE_LSTAT
+      if(t==file->SYMLINK)
+      {
+	 char *buf=(char*)alloca(st.st_size+1);
+	 int res=readlink(name,buf,st.st_size);
+	 if(res!=-1)
+	 {
+	    buf[res]=0;
+	    file->SetSymlink(buf);
+      	 }
+      }
+#endif /* HAVE_LSTAT */
+   }
+
+   done=true;
+   return MOVED;
+}
