@@ -22,6 +22,7 @@
 #define LOCALACCESS_H
 
 #include "FileAccess.h"
+#include "ListInfo.h"
 #include "Filter.h"
 
 class LocalAccess : public FileAccess
@@ -30,6 +31,8 @@ class LocalAccess : public FileAccess
    int error_code;
    bool done;
    void errno_handle();
+   void fill_array_info();
+
 public:
    void Init();
    LocalAccess();
@@ -39,7 +42,7 @@ public:
    const char *GetProto() { return "file"; }
    FileAccess *Clone() { return new LocalAccess(this); }
    static FileAccess *New() { return new LocalAccess(); }
-   bool SameLocationAs(FileAccess *fa,int force_level=0);
+   bool SameLocationAs(FileAccess *fa);
 
    int Read(void *buf,int size);
    int Write(const void *buf,int size);
@@ -49,6 +52,17 @@ public:
    void Close();
 
    static void ClassInit();
+
+   ListInfo *MakeListInfo();
+};
+
+class LocalListInfo : public ListInfo
+{
+   const char *dir;
+public:
+   LocalListInfo(const char *d) { dir=d; }
+   const char *Status() { return "..."; }
+   int Do();
 };
 
 #endif//LOCALACCESS_H
