@@ -32,11 +32,11 @@ void LsCache::CheckSize()
 {
    if(sizelimit<0)
       return;  // no limit
-      
+
    LsCache **oldest;
    time_t   oldest_time;
    LsCache **scan;
-   
+
    for(;;)
    {
       long size=0;
@@ -62,7 +62,7 @@ void LsCache::CheckSize()
 void LsCache::Add(FileAccess *p_loc,const char *a,int m,char *d,int l)
 {
    CheckSize();
-   
+
    LsCache *scan;
    for(scan=chain; scan; scan=scan->next)
    {
@@ -131,21 +131,39 @@ void LsCache::Flush()
 
 void LsCache::List()
 {
-   printf("Cache is %s\n",use?"ON":"OFF");
+   if(use)
+      puts(_("Cache is on"));
+   else
+      puts(_("Cache is off"));
    long vol=0;
    for(LsCache *scan=chain; scan; scan=scan->next)
       vol+=scan->data_len;
-   printf("%ld byte%s cached",vol,vol==1?"":"s");
+   if(vol==1)
+   	   // xgettext:c-format
+	   printf(_("1 byte cached"));
+   else
+	   printf(_("%ld bytes cached"),vol);
    if(sizelimit<0)
-      printf(", no size limit\n");
+      puts(_(", no size limit"));
    else
-      printf(", maximum size %ld\n",sizelimit);
+      printf(_(", maximum size %ld\n"),sizelimit);
    if(ttl==0)
-      printf("Cache entries do not expire\n");
+      puts(_("Cache entries do not expire"));
    else if(ttl<60)
-      printf("Cache entries expire in %ld second%s\n",(long)ttl,ttl==1?"":"s");
+   {
+      if(ttl==1)
+	      puts(_("Cache entries expire in 1 second"));
+      else
+	      printf(_("Cache entries expire in %ld seconds\n"),(long)ttl);
+   }
    else
-      printf("Cache entries expire in %ld minute%s\n",(long)(ttl+30)/60,(ttl+30)/60==1?"":"s");
+   {
+      long ttl_min=(long)(ttl+30)/60;
+      if(ttl_min==1)
+	      puts(_("Cache entries expire in 1 minute"));
+      else
+	      printf(_("Cache entries expire in %ld minutes\n"),ttl_min);
+   }
 }
 
 int LsCache::ExpireHelper::Do()
@@ -155,7 +173,7 @@ int LsCache::ExpireHelper::Do()
    time_t ct=time(0);
    if(!expiring || expiring->timestamp+ttl <= ct)
    {
-      LsCache **scan=&LsCache::chain; 
+      LsCache **scan=&LsCache::chain;
       while(*scan)
       {
 	 if((*scan)->timestamp+ttl <= ct)
