@@ -30,7 +30,7 @@ int ProcWait::Do()
    if(status!=RUNNING)
    {
    final:
-      if(flags&AUTODESTROY)
+      if(auto_die)
 	 return WANTDIE;
       block+=NoWait();
       return m;
@@ -59,6 +59,25 @@ int ProcWait::Do()
 	 goto final;
       }
    }
+   // FIXME: smart SIGCHLD handling...
    block+=TimeOut(200);
    return m;
 }
+
+int ProcWait::Kill(int sig)
+{
+   int res;
+   res=kill(-pid,sig);
+   if(res==-1)
+      res=kill(pid,sig);
+   return res;
+}
+
+ProcWait::ProcWait(pid_t p)
+{
+   auto_die=false;
+   pid=p;
+   status=RUNNING;
+   term_info=-1;
+   saved_errno=0;
+}
