@@ -34,50 +34,24 @@ public:
       RUNNING,
       ERROR
    };
-   enum
-   {
-      AUTODESTROY=1
-   };
 
 private:
    pid_t pid;
    State status;
    int	 term_info;
    int	 saved_errno;
-   int	 flags;
+   bool  auto_die;
 
 public:
    int	 Do();
    int	 GetState() { return status; }
    int	 GetErrno() { return saved_errno; }
    int	 GetInfo() { return term_info; }
-   int	 Kill(int sig=SIGTERM)
-   {
-      int res;
-      res=kill(-pid,sig);
-      if(res==-1)
-	 res=kill(pid,sig);
-      return res;
-   }
+   int	 Kill(int sig=SIGTERM);
 
-   void	 SetFlag(int flag,int val)
-   {
-      if(val)
-	 flags|=flag;
-      else
-	 flags&=~flag;
-   }
+   void Auto() { auto_die=true; }
 
-   void Auto() { flags|=AUTODESTROY; }
-
-   ProcWait(pid_t p)
-   {
-      flags=0;
-      pid=p;
-      status=RUNNING;
-      term_info=-1;
-      saved_errno=0;
-   }
+   ProcWait(pid_t p);
 };
 
 #endif /* PROCWAIT_H */
