@@ -39,8 +39,10 @@ public:
       : FileXfer(s,args,cont)
    {
       remote_size=0;
+#if 0
       if(!curr && args && args->count()>1)
 	 NextFile();
+#endif
    }
 };
 
