@@ -20,6 +20,7 @@
 
 #include <config.h>
 
+#include <fnmatch.h>
 #include "ResMgr.h"
 #include "SMTask.h"
 #include "xmalloc.h"
@@ -82,11 +83,11 @@ const char *ResMgr::FindVar(const char *name,ResDecl **type)
       }
    }
    if(!type_scan && sub==0)
-      return "no such variable";
+      return _("no such variable");
    if(sub==1)
       return 0;
    *type=0;
-   return "ambiguous variable name";
+   return _("ambiguous variable name");
 }
 
 const char *ResMgr::Set(const char *name,const char *cclosure,const char *cvalue)
@@ -242,7 +243,7 @@ const char *ResMgr::BoolValidate(char **value)
    case 'o':   newval=(v[1]=='f' || v[1]=='F')?"off":"on";  break;
    case 'O':   newval=(v[1]=='f' || v[1]=='F')?"Off":"On";  break;
    default:
-      return "invalid boolean value";
+      return _("invalid boolean value");
    }
    if(strcmp(v,newval))
    {
@@ -265,7 +266,7 @@ const char *ResMgr::NumberValidate(char **value)
    int n=strspn(v,"1234567890");
 
    if(n==0)
-      return "invalid number";
+      return _("invalid number");
 
    v[n]=0;
 
@@ -281,13 +282,22 @@ const char *ResMgr::UNumberValidate(char **value)
    int n=strspn(v,"1234567890");
 
    if(n==0)
-      return "invalid number";
+      return _("invalid number");
 
    v[n]=0;
 
    return 0;
 }
 
+bool ResMgr::Resource::ClosureMatch(const char *cl_data)
+{
+   if(!closure && !cl_data)
+      return true;
+   if(!(closure && cl_data))
+      return false;
+   return 0==fnmatch(closure,cl_data,FNM_PATHNAME);
+}
+
 const char *ResMgr::Query(const char *name,const char *closure)
 {
    const char *msg;
@@ -301,10 +311,7 @@ const char *ResMgr::Query(const char *name,const char *closure)
    Resource **scan;
    // find the old value
    for(scan=&chain; *scan; scan=&(*scan)->next)
-      if((*scan)->type==type
-	 && ((closure==0 && (*scan)->closure==0)
-	     || (closure && (*scan)->closure
-	         && !strcmp((*scan)->closure,closure))))
+      if((*scan)->type==type && (*scan)->ClosureMatch(closure))
 	 break;
 
    // if found
