@@ -134,12 +134,13 @@ int   Resolver::Do()
       goto proto_error;
    if(c=='E') // error
    {
-      char buf[256];
-      res=read(pipe_to_child[0],buf,sizeof(buf));
+      char buf[512];
+      res=read(pipe_to_child[0],buf,sizeof(buf)-1);
       if(res<0)
 	 goto read_error;
+      buf[res]=0;
       err_msg=(char*)xmalloc(strlen(hostname)+res+3);
-      sprintf(err_msg,"%s: %.*s",hostname,res,buf);
+      sprintf(err_msg,"%s: %s",hostname,buf);
       done=true;
       return MOVED;
    }
