@@ -33,9 +33,8 @@ void SignalHook::cnt_handler(int sig)
 void SignalHook::set_signal(int sig,void (*handler)(int))
 {
    void (*old)(int);
-
    old=signal(sig,SIG_IGN);
-   if(old!=SIG_IGN)
+   if(old!=(void(*)(int))SIG_IGN)
       signal(sig,handler);
    if(old_handlers[sig]==0)
       old_handlers[sig]=old;
