@@ -35,7 +35,7 @@ public:
    static void ResetCount(int sig) { counts[sig]=0; }
    static void IncreaseCount(int sig) { counts[sig]++; }
    static void AddHook(int sig,void (*)(int));
-   static void Ignore(int sig) { set_signal(sig,SIG_IGN); }
+   static void Ignore(int sig) { set_signal(sig,(void (*)(int))SIG_IGN); }
    static void Restore(int sig);
    static void RestoreAll();
 };
