@@ -21,12 +21,10 @@
 #ifndef STATUSLINE_H
 #define STATUSLINE_H
 
-#ifndef PRINTF_LIKE
-# ifdef __GNUC__
-#  define PRINTF_LIKE __attribute__((format(printf,2,3)))
-# else
-#  define PRINTF_LIKE
-# endif
+#ifdef __GNUC__
+# define PRINTF_LIKE(n,m) __attribute__((format(printf,n,m)))
+#else
+# define PRINTF_LIKE(n,m)
 #endif
 
 class StatusLine
@@ -37,8 +35,8 @@ class StatusLine
 
 public:
    int GetWidth();
-   void Show(const char *f,...) PRINTF_LIKE;
-   void WriteLine(const char *f,...) PRINTF_LIKE;
+   void Show(const char *f,...) PRINTF_LIKE(2,3);
+   void WriteLine(const char *f,...) PRINTF_LIKE(2,3);
 
    int getfd() { return fd; }
 
