@@ -32,6 +32,7 @@
 #include "alias.h"
 #include "GetPass.h"
 #include "SignalHook.h"
+#include "CharReader.h"
 
 extern "C" {
 #include "readline/readline.h"
@@ -655,6 +656,29 @@ int   lftp_complete_remote(int count,int key)
 }
 }
 
+int   lftp_rl_getc(FILE *file)
+{
+   int res;
+   CharReader r(fileno(file));
+
+   for(;;)
+   {
+      SMTask::Schedule();
+      res=r.GetChar();
+      if(res==r.EOFCHAR)
+	 return EOF;
+      if(res!=r.NOCHAR)
+	 return res;
+      SMTask::Block();
+      if(SignalHook::GetCount(SIGINT)>0)
+      {
+	 rl_kill_text(0,rl_end);
+	 rl_line_buffer[0]=0;
+	 return '\n';
+      }
+   }
+}
+
 /* Tell the GNU Readline library how to complete.  We want to try to complete
    on command names if this is the first word in the line, or on filenames
    if not. */
