@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-1998 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,10 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <ctype.h>
+#include <fcntl.h>
+#ifdef HAVE_LOCALE_H
+# include <locale.h>
+#endif
 
 #include "xalloca.h"
 #include "ftpclass.h"
@@ -39,6 +43,9 @@
 #include "CmdExec.h"
 #include "SignalHook.h"
 #include "GetPass.h"
+#include "history.h"
+
+#include "confpaths.h"
 
 extern "C" {
 #include "readline/readline.h"
@@ -51,7 +58,6 @@ void  hook_signals()
 {
    SignalHook::DoCount(SIGHUP);
    SignalHook::DoCount(SIGPIPE);
-//    SignalHook::DoCount(SIGCHLD);
    SignalHook::Ignore(SIGTTOU);
 }
 
@@ -90,6 +96,7 @@ public:
       char *cmd_buf;
       if(tty)
       {
+	 SignalHook::ResetCount(SIGINT);
 	 cmd_buf=xstrdup(readline(prompt));
 	 if(cmd_buf && *cmd_buf)
 	 {
@@ -122,6 +129,8 @@ public:
 	       add_history(cmd_buf);
 	    using_history();
 	 }
+	 else if(cmd_buf==0 && exec->interactive)
+	    puts("exit");
       }
       else
 	 cmd_buf=xstrdup(readline_from_file(stdin));
@@ -138,8 +147,78 @@ public:
    }
 };
 
+static void move_to_background()
+{
+   fflush(stdout);
+   fflush(stderr);
+   pid_t pid=fork();
+   switch(pid)
+   {
+   case(0): // child
+   {
+      SignalHook::Ignore(SIGINT);
+      SignalHook::Ignore(SIGQUIT);
+      SignalHook::Ignore(SIGHUP);
+      SignalHook::Ignore(SIGTSTP);
+
+      char *home=getenv("HOME");
+      if(!home) home=".";
+
+      char *log=(char*)alloca(strlen(home)+1+9+1);
+      sprintf(log,"%s/.lftp",home);
+      if(access(log,F_OK)==-1)
+	 strcat(log,"_log");
+      else
+	 strcat(log,"/log");
+
+      int fd=open(log,O_WRONLY|O_APPEND|O_CREAT,0600);
+      if(fd>=0)
+      {
+	 dup2(fd,1);
+	 dup2(fd,2);
+	 if(fd!=1 && fd!=2)
+	    close(fd);
+      }
+      pid=getpid();
+      time_t t=time(0);
+      printf(_("[%lu] Started.  %s"),(unsigned long)pid,ctime(&t));
+      for(;;)
+      {
+	 SMTask::Schedule();
+	 if(Job::NumberOfJobs()==0)
+	    break;
+	 SMTask::Block();
+      }
+      t=time(0);
+      printf(_("[%lu] Finished. %s"),(unsigned long)pid,ctime(&t));
+      return;
+   }
+   default: // parent
+      printf(_("[%lu] Moving to background to complete transfers...\n"),
+	       (unsigned long)pid);
+      fflush(stdout);
+      _exit(0);
+   case(-1):
+      perror("fork()");
+   }
+}
+
+void  source_if_exist(CmdExec *exec,char *rc)
+{
+   if(access(rc,R_OK)!=-1)
+   {
+      exec->FeedCmd("source ");
+      exec->FeedCmd(rc);
+      exec->FeedCmd("\n");
+   }
+}
+
 int   main(int argc,char **argv)
 {
+   setlocale (LC_ALL, "");
+   bindtextdomain (PACKAGE, LOCALEDIR);
+   textdomain (PACKAGE);
+
    LocalAccess::ClassInit();
    Ftp::ClassInit();
 
@@ -154,37 +233,43 @@ int   main(int argc,char **argv)
 
    hook_signals();
 
-   if(access("/etc/lftp.conf",R_OK)!=-1)
-      top_exec->FeedCmd("source /etc/lftp.conf\n");
+   source_if_exist(top_exec,SYSCONFDIR"/lftp.conf");
+
+   char	 *rc=(char*)alloca(strlen(home)+9+1);
+
+   // create lftp own directory
+   sprintf(rc,"%s/.lftp",home);
+   mkdir(rc,0755);
+
+   sprintf(rc,"%s/.lftprc",home);
+   source_if_exist(top_exec,rc);
+   sprintf(rc,"%s/.lftp/rc",home);
+   source_if_exist(top_exec,rc);
 
-   char	 *rc=(char*)alloca(7+strlen(home)+8+1);
-   sprintf(rc,"source %s/.lftprc",home);
-   if(access(rc+7,R_OK)!=-1)
-   {
-      top_exec->FeedCmd(rc);
-      top_exec->FeedCmd("\n");
-   }
    WaitDone(top_exec);
 
+   top_exec->SetCmdFeeder(new ReadlineFeeder);
+
    top_exec->SetInteractive(isatty(0));
-   top_exec->bootstrap=true;
-   char *slash=strrchr(argv[0],'/');
-   if(slash)
-      memmove(argv[0],slash+1,strlen(slash));
-   top_exec->ExecParsed(new ArgV(argc,argv));
 
-   WaitDone(top_exec);
-   top_exec->bootstrap=false;
-
-   if(!top_exec->want_terminate)
+   ArgV *args=new ArgV(argc,argv);
+   args->setarg(0,"lftp");
+   if(args->count()>1)
    {
-      top_exec->SetCmdFeeder(new ReadlineFeeder);
-      WaitDone(top_exec);
-
-      if(top_exec->interactive)
-	 puts("exit");
+      char *line=args->Combine();
+      add_history(line);
+      free(line);
    }
-   top_exec->FeedCmd("exit\n");
+   top_exec->ExecParsed(args);
+
    WaitDone(top_exec);
+
+   cwd_history.Save();
+
+   if(Job::NumberOfJobs()>0)
+   {
+      top_exec->interactive=false;
+      move_to_background();
+   }
    return top_exec->ExitCode();
 }
