@@ -27,7 +27,7 @@ void mgetJob::ShowRunStatus(StatusLine *s)
 {
    if(rg)
    {
-      s->Show("Getting file list [%s]",session->CurrentStatus());
+      s->Show(_("Getting file list [%s]"),session->CurrentStatus());
       return;
    }
    GetJob::ShowRunStatus(s);
@@ -37,7 +37,9 @@ void mgetJob::PrintStatus(int v)
    if(rg)
    {
       SessionJob::PrintStatus(v);
-      printf("\tGetting file list [%s]\n",session->CurrentStatus());
+      putchar('\t');
+      printf(_("Getting file list [%s]"),session->CurrentStatus());
+      putchar('\n');
       return;
    }
    GetJob::PrintStatus(v);
@@ -67,7 +69,7 @@ mgetJob::mgetJob(FileAccess *session,ArgV *args) : GetJob(session,new ArgV(args-
 	 break;
       case('?'):
       print_usage:
-	 printf("Usage: %s [-c] [-d] [-e] pattern ...\n",args->getarg(0));
+	 printf(_("Usage: %s [-c] [-d] [-e] pattern ...\n"),args->getarg(0));
 	 return;
       }
    }
@@ -105,7 +107,7 @@ int mgetJob::Do()
    files=rg->GetResult();
    if(!files)
    {
-      fprintf(stderr,"%s: no files found\n",rg->pattern);
+      fprintf(stderr,_("%s: no files found\n"),rg->pattern);
       goto next;
    }
    for(i=files; *i; i++)
