@@ -28,9 +28,14 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include "misc.h"
+#include "ProcWait.h"
+#include "SignalHook.h"
 
-char  *dir_file(const char *dir,const char *file)
+const char *dir_file(const char *dir,const char *file)
 {
+   if(dir==0 || dir[0]==0 || file[0]=='/')
+      return file;
+
    static char *buf=0;
    static int buf_size=0;
    int len=strlen(dir)+1+strlen(file)+1;
@@ -49,8 +54,12 @@ char  *dir_file(const char *dir,const char *file)
 
 char *basename_ptr(char *s)
 {
-   char *s1=strrchr(s,'/');
-   return s1?s1+1:s;
+   char *s1=s+strlen(s);
+   while(s1>s && s1[-1]=='/')
+      s1--;
+   while(s1>s && s1[-1]!='/')
+      s1--;
+   return s1;
 }
 
 char *expand_home_relative(char *s)
@@ -60,7 +69,7 @@ char *expand_home_relative(char *s)
       char *home=0;
       char *sl;
       static char *ret_path=0;
-      
+
       if(s[1]==0 || s[1]=='/')
       {
 	 home=getenv("HOME");
@@ -73,14 +82,14 @@ char *expand_home_relative(char *s)
 	 sl=strchr(name,'/');
 	 if(sl)
 	    *sl=0;
-	    
+
 	 struct passwd *pw=getpwnam(name);
 	 if(pw)
 	    home=pw->pw_dir;
       }
       if(home==0)
 	 return s;
-      
+
       sl=strchr(s,'/');
       if(sl)
       {
@@ -112,15 +121,18 @@ int   create_directories(char *path)
       }
       if(sl)
 	 *sl=0;
-      res=mkdir(path,0755);
-      if(res==-1)
+      if(access(path,0)==-1)
       {
-	 if(errno!=EEXIST)
+	 res=mkdir(path,0755);
+	 if(res==-1)
 	 {
-	    fprintf(stderr,"mkdir(%s): %s\n",path,strerror(errno));
-      	    if(sl)
-	       *sl='/';
-	    return(-1);
+	    if(errno!=EEXIST)
+	    {
+	       fprintf(stderr,"mkdir(%s): %s\n",path,strerror(errno));
+	       if(sl)
+		  *sl='/';
+	       return(-1);
+	    }
 	 }
       }
       if(sl)
@@ -130,3 +142,26 @@ int   create_directories(char *path)
    }
    return 0;
 }
+
+void  truncate_file_tree(const char *dir)
+{
+   fflush(stderr);
+   pid_t pid;
+   switch(pid=fork())
+   {
+   case(0): // child
+      SignalHook::Ignore(SIGINT);
+      SignalHook::Ignore(SIGTSTP);
+      SignalHook::Ignore(SIGQUIT);
+      SignalHook::Ignore(SIGHUP);
+      execlp("rm","rm","-rf",dir,NULL);
+      perror("execlp(rm)");
+      fflush(stderr);
+      _exit(1);
+   case(-1):   // error
+      perror("fork()");
+      return;
+   default: // parent
+      (new ProcWait(pid))->Auto();  // don't wait for termination
+   }
+}
