@@ -26,11 +26,18 @@ char *expand_home_relative(char *);
 
 // returns ptr to last path element
 char *basename_ptr(char *);
+inline const char *basename_ptr(const char *f)
+{
+   return (const char*)basename_ptr((char*)f);
+}
 
 // clues file to dir; returns pointer to static storage
-char *dir_file(const char *dir,const char *file);
+const char *dir_file(const char *dir,const char *file);
 
 // mkdir -p
 int   create_directories(char *);
 
+// rm -rf
+void  truncate_file_tree(const char *dir);
+
 #endif // MISC_H
