@@ -103,9 +103,10 @@ void  mkdirJob::SayFinal()
       return;
    char *op=args->getarg(0);
    if(file_count==1)
-      printf("%s ok, `%s' created\n",op,first);
+      // A directory has just been created
+      printf(_("%s ok, `%s' created\n"),op,first);
    else if(failed)
-      printf("%s failed for %d of %d directories\n",op,failed,file_count);
+      printf(_("%s failed for %d of %d directories\n"),op,failed,file_count);
    else
-      printf("%s ok, %d directories created\n",op,file_count);
+      printf(_("%s ok, %d directories created\n"),op,file_count);
 }
