@@ -30,13 +30,14 @@ CmdExec::parse_result CmdExec::parse_one_cmd()
 {
    int	 in_quotes;
 
-#define quotable(ch) (strchr("\"\\",ch) \
-		      || (!in_quotes && strchr(" \t>|;&",ch)))
+#define quotable(ch) (ch && (strchr("\"\\",ch) \
+		             || (!in_quotes && strchr(" \t>|;&",ch))))
 
    char *line=next_cmd;
    static char *nextarg=0;
    char *endarg;
    const char *alias=0;
+   char *old_next_cmd=next_cmd;
 
    if(args)
       args->Empty();
@@ -57,7 +58,7 @@ CmdExec::parse_result CmdExec::parse_one_cmd()
    char *redir_file=0;
    background=0;
 
-   if(line==0)
+   if(line==0 || *line==0)
    {
       // empty command
       return PARSE_OK;
@@ -82,15 +83,21 @@ CmdExec::parse_result CmdExec::parse_one_cmd()
    for(;;)
    {
       // skip leading whitespace
-      while(*line==' ' || *line=='\t' || (args->count()==0 && *line=='\n'))
+      while(*line==' ' || *line=='\t')
 	 line++;
 
+      if(line[0]=='\\' && line[1]=='\n')
+      {
+	 line+=2;
+	 continue;   // and continue skipping space
+      }
+
       if(*line==0 || *line=='\n'
       || *line=='|' || *line=='>' || *line==';' || *line=='&')
 	 break;
 
       nextarg=(char*)xrealloc(nextarg,strlen(line)+1);
-      
+
       // endarg points just beyond the last char of arg
       endarg=nextarg;
 
@@ -102,6 +109,7 @@ CmdExec::parse_result CmdExec::parse_one_cmd()
 	 next_cmd=line;
 	 if(*next_cmd=='\n')
 	    next_cmd++;
+	 alias_field-=next_cmd-old_next_cmd;
 	 return PARSE_OK;
       }
 
@@ -129,6 +137,7 @@ CmdExec::parse_result CmdExec::parse_one_cmd()
 	 *endarg=0;
 	 if(*nextarg)
 	    args->Append(nextarg);
+	 alias_field-=next_cmd-old_next_cmd;
 	 return PARSE_OK;
       }
 
@@ -202,39 +211,53 @@ CmdExec::parse_result CmdExec::parse_one_cmd()
 	 *endarg++=*line++;
       }
       if(*line==0)
-	 return PARSE_AGAIN;  // normal commands finish with \n
+	 return PARSE_AGAIN;  // normal commands finish with \n or ;
       *endarg=0;
       if(args->count()==0)
       {
 	 alias=Alias::Find(nextarg);
-      	 if(alias && !TouchedAlias::IsTouched(alias,used_aliases))
+      	 if(alias)
 	 {
-	    used_aliases=new TouchedAlias(alias,used_aliases);
 	    int alias_len=strlen(alias);
-	    if(line-cmd_buf < alias_len)
+	    if(alias_field<=(int)(line-next_cmd-alias_len))
 	    {
-	       int offs=line-cmd_buf;
-	       int line_len=strlen(line);
-	       cmd_buf=(char*)xrealloc(cmd_buf,line_len+1+alias_len);
-	       memmove(cmd_buf+alias_len,cmd_buf+offs,line_len+1);
-	       line=cmd_buf;
+	       free_used_aliases();
+	       old_next_cmd=next_cmd;
 	    }
-	    else
+	    if(!TouchedAlias::IsTouched(alias,used_aliases))
 	    {
-	       line-=alias_len;
+	       alias_field-=next_cmd-old_next_cmd;
+	       used_aliases=new TouchedAlias(alias,used_aliases);
+	       if(line-cmd_buf < alias_len)
+	       {
+		  int offs=line-cmd_buf;
+		  int line_len=strlen(line);
+		  cmd_buf=(char*)xrealloc(cmd_buf,line_len+1+alias_len);
+		  memmove(cmd_buf+alias_len,cmd_buf+offs,line_len+1);
+		  line=cmd_buf;
+	       }
+	       else
+	       {
+		  line-=alias_len;
+	       }
+	       memcpy(line,alias,alias_len);
+	       old_next_cmd=next_cmd=line;
+	       alias_field+=alias_len;
+	       continue;
 	    }
-	    memcpy(line,alias,alias_len);
-	    next_cmd=line;
-	    continue;
 	 }
       }
       args->Append(nextarg);
    }
 
+   if(*line==0)
+      return PARSE_AGAIN;
+
    if((line[0]=='&' && line[1]=='&')
    || (line[0]=='|' && line[1]=='|'))
    {
       next_cmd=line;
+      alias_field-=next_cmd-old_next_cmd;
       return PARSE_OK;
    }
 
@@ -255,11 +278,16 @@ CmdExec::parse_result CmdExec::parse_one_cmd()
 
       if(*line==0 || *line=='\n' || *line==';' || *line=='&')
       {
-	 fprintf(stderr,"Missing %s\n",redir_type=='|'?"filter command":"filename");
+	 if(redir_type=='|')
+	    eprintf(_("parse: missing filter command\n"));
+	 else
+	    eprintf(_("parse: missing redirection filename\n"));
+
 	 if(*line==';' || *line=='&' || *line=='\n')
 	    next_cmd=line+1;
 	 else
 	    next_cmd=line;
+	 alias_field-=next_cmd-old_next_cmd;
 	 return PARSE_ERR;
       }
 
@@ -313,6 +341,7 @@ cmd_end:
    {
       next_cmd=line;
    }
+   alias_field-=next_cmd-old_next_cmd;
 
    switch(redir_type)
    {
