@@ -21,20 +21,24 @@
 #include <config.h>
 #include "pgetJob.h"
 
+#undef MIN
 #define MIN(a,b) ((a)<(b)?(a):(b))
 
 int pgetJob::Do()
 {
    int m=STALL;
-   
+
+   if(curr==0)
+      return GetJob::Do();
+
    if(no_parallel || max_chunks<2)
-      return GetJob::Do(); 
+      return GetJob::Do();
 
    if(chunks==0 || offset<chunks[0]->start)
       m=GetJob::Do();
    else
       session->Suspend();
-      
+
    if(Done())
       return m;
 
@@ -42,7 +46,7 @@ int pgetJob::Do()
    {
       if(size==-1)
 	 return m;
-   
+
       /* initialize chunks */
       long chunk_size=(size-offset)/max_chunks;
       if(chunk_size<0x10000)
@@ -67,10 +71,11 @@ int pgetJob::Do()
       }
       m=MOVED;
    }
-   
+
    /* cycle through the chunks */
    chunks_done=true;
    total_xferred=MIN(offset,chunks[0]->start);
+   total_xfer_rate=minute_xfer_rate;
    for(int i=0; i<num_of_chunks; i++)
    {
       if(chunks[i]->error)
@@ -79,10 +84,13 @@ int pgetJob::Do()
 	 break;
       }
       total_xferred+=MIN(chunks[i]->offset,chunks[i]->limit)-chunks[i]->start;
+      total_xfer_rate+=chunks[i]->minute_xfer_rate;
+      if(last_bytes<chunks[i]->last_bytes)
+	 last_bytes=chunks[i]->last_bytes;
       if(!chunks[i]->Done())
 	 chunks_done=false;
    }
-   
+
    if(no_parallel)
    {
       free_chunks();
@@ -91,6 +99,8 @@ int pgetJob::Do()
 
    if(chunks_done && offset>=chunks[0]->start)
    {
+      if(file_time>=0)
+	 local->setmtime(file_time);
       NextFile();
       return MOVED;
    }
@@ -105,21 +115,34 @@ void pgetJob::ShowRunStatus(StatusLine *s)
 
    if(Done() || no_parallel || max_chunks<2 || !chunks)
    {
-      GetJob::ShowRunStatus(s); 
+      GetJob::ShowRunStatus(s);
       return;
    }
-   
-   if(curr && session->IsOpen())
-   {
-      int w=s->GetWidth()-20;
-      if(w<=0)
-	 return;
-      char *n=curr;
-      if((int)strlen(n)>w)
-	 n=n+strlen(n)-w;
-      s->Show("`%s', got %lu of %lu (%d%%)",n,total_xferred,size,
-	    percent(total_xferred,size));
-   }
+
+   if(!curr || !session->IsOpen())
+      return;
+
+   time_t now=time(0);
+   if(now==last_status_update)
+      return;
+   last_status_update=now;
+
+   int w=s->GetWidth()-30;
+   if(w<=0)
+      return;
+   char *n=curr;
+   if((int)strlen(n)>w)
+      n=n+strlen(n)-w;
+   // xgettext:c-format
+   s->Show(_("`%s', got %lu of %lu (%d%%) %s"),n,total_xferred,size,
+	 percent(total_xferred,size),CurrRate(total_xfer_rate));
+}
+
+// list subjobs (chunk xfers) only when verbose
+void  pgetJob::ListJobs(int verbose,int indent)
+{
+   if(verbose>1)
+      Job::ListJobs(verbose,indent);
 }
 
 void  pgetJob::PrintStatus(int verbose)
@@ -134,10 +157,16 @@ void  pgetJob::PrintStatus(int verbose)
 
    if(curr && session->IsOpen())
    {
-      printf("\t`%s', got %lu of %lu (%d%%)\n",curr,total_xferred,size,
-	    percent(total_xferred,size));
-      printf("\tat %ld (%d%%) [%s]\n",MIN(offset,chunks[0]->start),
-	    percent(offset,chunks[0]->start),session->CurrentStatus());
+      putchar('\t');
+      printf(_("`%s', got %lu of %lu (%d%%) %s"),curr,total_xferred,size,
+	    percent(total_xferred,size),CurrRate(total_xfer_rate));
+      putchar('\n');
+      if(verbose>1)
+      {
+	 // xgettext:c-format
+	 printf(_("\tat %ld (%d%%) [%s]\n"),MIN(offset,chunks[0]->start),
+	       percent(offset,chunks[0]->start),session->CurrentStatus());
+      }
    }
 }
 
@@ -160,7 +189,7 @@ pgetJob::~pgetJob()
 void pgetJob::NextFile()
 {
    free_chunks();
-   
+
    GetJob::NextFile();
    no_parallel=false;
    total_xferred=0;
@@ -193,12 +222,14 @@ pgetJob::ChunkXfer::~ChunkXfer()
 
 int pgetJob::ChunkXfer::Do()
 {
+   RateDrain();
+
    int m=STALL;
    int res;
 
    if(done)
       return STALL;
-      
+
    if(in_buffer==0 && got_eof)
    {
       session->Close();
@@ -246,7 +277,7 @@ int pgetJob::ChunkXfer::Do()
    }
    if(res>0)
       m=MOVED;
-   
+
    return m;
 }
 
@@ -254,13 +285,14 @@ void  pgetJob::ChunkXfer::PrintStatus(int)
 {
    if(done)
    {
-      printf("\tDone\n");
+      // xgettext:c-format
+      printf(_("\tDone\n"));
       return;
    }
 
    if(curr && session->IsOpen())
    {
-      printf("\tat %ld (%d%%) [%s]\n",offset,percent(offset-start,limit-start),
+      printf(_("\tat %ld (%d%%) [%s]\n"),offset,percent(offset-start,limit-start),
 			      session->CurrentStatus());
    }
 }
