@@ -28,7 +28,7 @@ class pgetJob : public GetJob
    class ChunkXfer : public XferJob
    {
       friend class pgetJob;
-      
+
       long start;
       long limit;
       char *error_text;
@@ -36,24 +36,25 @@ class pgetJob : public GetJob
       bool done:1;
       bool no_parallel:1;
       FDStream *local;
-      
+
       ChunkXfer(FileAccess *session,char *remote,FDStream *local,
 	        long start,long limit);
       ~ChunkXfer();
-      
+
       int Do();
       int Done() { return done; }
       void PrintStatus(int);
    };
-	 
+
    ChunkXfer   **chunks;
    int	 max_chunks;
    int	 num_of_chunks;
    long	 total_xferred;
+   float total_xfer_rate;
 
    bool	no_parallel:1;
    bool chunks_done:1;
-   
+
    void free_chunks();
 
 protected:
@@ -63,13 +64,15 @@ public:
    int Do();
    void ShowRunStatus(StatusLine *s);
    void PrintStatus(int);
-   
+   void ListJobs(int verbose,int indent=0);
+
    pgetJob(FileAccess *s,ArgV *args)
       : GetJob(s,args,/*cont=*/false)
    {
       chunks=0;
       num_of_chunks=0;
       total_xferred=0;
+      total_xfer_rate=0;
       no_parallel=false;
       max_chunks=5;
       need_seek=true; // seek before writing
