@@ -55,11 +55,21 @@ ParsedURL::ParsedURL(const char *url)
 
       base=scan;
    }
+   else if(scan[0]==':' && !strncmp(base,"file:",5))
+   {
+      // special form for file protocol
+      *scan=0;
+      scan++;
+      proto=base;
+      path=scan;
+      host="localhost";
+      return;
+   }
 
    scan=base;
    while(*scan && *scan!='/')
       scan++; // skip host name, port and user:pass
-   
+
    if(*scan=='/') // directory
    {
       if(scan-1>=base && scan[-1]==':')
@@ -69,7 +79,7 @@ ParsedURL::ParsedURL(const char *url)
       *scan++=0;
       path=scan;
    }
-   
+
    // try to extract user name/password
    scan=base;
    while(*scan && *scan!='@')
@@ -89,13 +99,13 @@ ParsedURL::ParsedURL(const char *url)
 	 pass=scan;
       }
    }
-   
+
    // extract host name/password
    scan=base;
    host=base;
    while(*scan && *scan!=':')
       scan++;
-   
+
    if(*scan==':') // port found
    {
       *scan++=0;
